<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>MX instalátor kodeků</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some jurisdictions, their distribution may be limited. Please check the regulations in your area. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Tato aplikace Vám umožní nainstalovat nesvobodné kodeky, které zpřístupňují pokročilé funkce videa a audia.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;V některých krajinách může být jejich šíření omezené. Prosím zkontrolujte si omezení pro vaší oblast. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Přebíráte právní zodpovědnost za stažení těchto kodeků?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Stahuji kodeky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Cancel any changes then quit</source>
        <translation>Zrušit všechny změny a ukončit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Begin codec download and installation</source>
        <translation>Začít stahování a instalaci kodeku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Spouštím příkaz...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="151"/>
        <location filename="../mainwindow.cpp" line="171"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>Cannot connect to the download site</source>
        <translation>Nelze se připojit k stránce</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Error downloading %1</source>
        <translation>Chyba stahování %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="152"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>downloading Packages.gz from &apos;main&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>downloading Packages.gz from &apos;non-free&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>downloading Packages.gz from i386 &apos;main&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Stahování dokončeno.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Cannot connect find %1 package</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Installing downloaded files</source>
        <translation>Instaluji stažené soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Nebyly nalezeny žádné *.deb (instalační) soubory.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Instaluje se...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Error installing %1</source>
        <translation>Chyba instalace %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>Fix missing dependencies...</source>
        <translation>Oprava chybějících závislostí...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Error running %1 command</source>
        <translation>Chyba spuštění příkazu %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Instalace dokončena&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>Finished</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Kodeky byly úspěšně staženy a nainstalovány.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Proces dokončen. Během instalace se vyskytly chyby. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>About MX Codecs</source>
        <translation>O MX Kodeky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MX Codecs</source>
        <translation type="vanished">MX Kodeky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Jednoduchý instalátor kodeků pro MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licence</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Protokol změn</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Unable to get exclusive lock</source>
        <translation type="vanished">Nebylo možné zamknout soubor</translation>
    </message>
    <message>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="vanished">Jiná aplikace pro správu softvéru (napr. Synaptic nebo apt-get) již běží.
Prosím nejdřiv ji ukončete</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Tuto aplikaci musíte spustit jako root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation type="unfinished">Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation type="unfinished">Protokol změn</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation type="unfinished">Zrušit</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished">Chyba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished">Nebylo možné zamknout soubor</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="unfinished">Jiná aplikace pro správu softvéru (napr. Synaptic nebo apt-get) již běží.
Prosím nejdřiv ji ukončete</translation>
    </message>
</context>
</TS>
